@@ -51,6 +51,12 @@ class TestCommodplot(unittest.TestCase):
         res = commodplot.reindex_year_line_plot(sp)
         self.assertTrue(isinstance(res, go.Figure))
 
+    def test_fwd_hist_plot(self):
+        dirname, filename = os.path.split(os.path.abspath(__file__))
+        cl = pd.read_csv(os.path.join(dirname, 'test_cl_fwd.csv'), index_col=0, parse_dates=True, dayfirst=True)
+        res = commodplot.forward_history_plot(cl)
+        self.assertTrue(isinstance(res, go.Figure))
+
     def test_reindex_year_line_subplot(self):
         dr = pd.date_range(start='2015', end='2020-12-31', freq='B')
         data = {'Q1 2019': [10 for x in dr], 2020: [20 for x in dr], 2021: [30 for x in dr], 2022: [10 for x in dr]}
@@ -95,10 +101,22 @@ class TestCommodplot(unittest.TestCase):
         self.assertTrue(isinstance(res, go.Figure))
 
     def test_line_plot(self):
+        dirname, filename = os.path.split(os.path.abspath(__file__))
+        cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
+        cl = cl.dropna(how='all', axis=1)[['CL_2019F', 'CL_2020G']]
+        fwd = pd.DataFrame([[50 for x in range(2)]], index=pd.date_range('2021-01-01', periods=12, freq='MS'), columns=['CL_2019F', 'CL_2020G'])
+
+        res = commodplot.line_plot(cl, fwd=fwd, title='Test')
+        self.assertTrue(isinstance(res, go.Figure))
+
+    def test_line_plot2(self):
         dirname, filename = os.path.split(os.path.abspath(__file__))
         cl = pd.read_csv(os.path.join(dirname, 'test_cl.csv'), index_col=0, parse_dates=True, dayfirst=True)
         cl = cl.dropna(how='all', axis=1)[['CL_2020F', 'CL_2020G']]
-        res = commodplot.line_plot(cl, title='Test')
+        cl = cl.rename(columns={'CL_2020F' : 'A', 'CL_2020G' : 'B'})
+        fwd = pd.DataFrame([[50 for x in range(2)]], index=pd.date_range('2021-01-01', periods=12, freq='MS'), columns=['A', 'B'])
+
+        res = commodplot.line_plot(cl, fwd=fwd, title='Test')
         self.assertTrue(isinstance(res, go.Figure))
 
 
